@@ -1,4 +1,5 @@
 import json
+from tests.integration.conftest import register_account
 
 from toot import App, User, api, cli
 from toot.entities import Account, Relationship, from_dict
@@ -35,9 +36,8 @@ def test_whois(app: App, friend: User, run):
         assert f"@{friend.username}" in result.stdout
 
 
-def test_following(app: App, user: User, friend: User, friend_id, run):
-    # Make sure we're not initally following friend
-    api.unfollow(app, user, friend_id)
+def test_following(app: App, user: User, run):
+    friend = register_account(app)
 
     result = run(cli.accounts.following, user.username)
     assert result.exit_code == 0
@@ -84,9 +84,8 @@ def test_following_not_found(run):
     assert result.stderr.strip() == "Error: Account not found"
 
 
-def test_following_json(app: App, user: User, friend: User, user_id, friend_id, run_json):
-    # Make sure we're not initally following friend
-    api.unfollow(app, user, friend_id)
+def test_following_json(app: App, user: User, user_id, run_json):
+    friend = register_account(app)
 
     result = run_json(cli.accounts.following, user.username, "--json")
     assert result == []
@@ -96,24 +95,26 @@ def test_following_json(app: App, user: User, friend: User, user_id, friend_id,
 
     result = run_json(cli.accounts.follow, friend.username, "--json")
     relationship = from_dict(Relationship, result)
-    assert relationship.id == friend_id
     assert relationship.following is True
 
     [result] = run_json(cli.accounts.following, user.username, "--json")
-    relationship = from_dict(Relationship, result)
-    assert relationship.id == friend_id
+    account = from_dict(Account, result)
+    assert account.acct == friend.username
 
     # If no account is given defaults to logged in user
-    [result] = run_json(cli.accounts.following, user.username, "--json")
-    relationship = from_dict(Relationship, result)
-    assert relationship.id == friend_id
+    [result] = run_json(cli.accounts.following, "--json")
+    account = from_dict(Account, result)
+    assert account.acct == friend.username
+
+    assert relationship.following is True
 
     [result] = run_json(cli.accounts.followers, friend.username, "--json")
-    assert result["id"] == user_id
+    account = from_dict(Account, result)
+    assert account.acct == user.username
 
     result = run_json(cli.accounts.unfollow, friend.username, "--json")
-    assert result["id"] == friend_id
-    assert result["following"] is False
+    relationship = from_dict(Relationship, result)
+    assert relationship.following is False
 
     result = run_json(cli.accounts.following, user.username, "--json")
     assert result == []
@@ -200,9 +201,8 @@ def test_mute_json(app: App, user: User, friend: User, run_json, friend_id):
     assert result == []
 
 
-def test_block(app, user, friend, friend_id, run):
-    # Make sure we're not initially blocking friend
-    api.unblock(app, user, friend_id)
+def test_block(app, user, run):
+    friend = register_account(app)
 
     result = run(cli.accounts.blocked)
     assert result.exit_code == 0
